@@ -1,5 +1,5 @@
 <?
-$modname = $_GET['mod'];
+$modname = getparam("mod",PAR_GET,SAN_FLAT);
 $myurl="index.php?mod=$modname&amp;file=";
 ?>
 
